General function for simultaneous CIs in a one-way layout using multivariate normal distribution.
Waldci(cmat, estp, varp, varcor, alternative = "two.sided", conf.level = 0.95, dist="MVN")A list containing:
a matrix with 2 columns: lower and upper confidence bounds, and M rows
character string, as input
single numeric value, as input
the quantile used to construct the CIs
Contrast matrix of dimension MxI, with M = the number of contrasts, I= the number of samples
numeric vector of point estimates of length I, with I = the number of samples
numeric vector of variance estimates of length I, to be used for interval construction
numeric vector of variance estimates of length I
character string
single numeric vector
a character string, "MVN" invokes multiplicity adjustment via the multivariate normal distribution,
"N" invokes use of quantiles of the univariate normal distribution
Frank Schaarschmidt
Mainly for internal use.
For user level implementations see:
binomRDci,
binomORci,
poly3ci