estSimpson: Simpson index

estSimpsonR Documentation

Simpson index

Description

Calculates the estimate of the Simpson index from a vector of counts.

Usage

estSimpson(x)

Arguments

x

a integer (numeric) vector, giving the counts of p species in a community


MCPAN documentation built on May 8, 2026, 9:06 a.m.