| scalechoice | R Documentation |
How to define scale parameters of the Weibull distribution in the poly-k-setting
scalechoice(shape = 3, pm = 0.2, t = 1)
shape |
shape parameter (usually shape=3) |
pm |
a numeric value (0<p<1), probability that an individual dies before time t |
t |
a numeric value, time t |
a single numeric value, giving the scale parameter needed to fulfill pm(t) for the current definition of the Weibull disstribution.
Scale parameter is defined differently than that in Peddada (2005)
?pweibull
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.