Produces a detailed print out of the results of function Simpsonci.
Usage
# S3 method for Simpsonci
summary(object, ...)
Value
A print out, comprising a table of the (possibly aggregated) data used for estimation,
the sample estimates for the Simpsons index, and its variance estimates,
the used contrast matrix, and the confidence intervals.
Arguments
object
an object of class "Simpsonci" as obtained by calling Simpsonci
...
further arguments to be passed to print and round: currently only digits