| summary.binomRDci | R Documentation |
Produces a more detailed print out of objects of class "binomRDci", including summary statistics, the used contrast matrix and the confidence intervals.
## S3 method for class 'binomRDci'
summary(object, ...)
object |
an object of class "binomRDci" as created by function binomRDci |
... |
further arguments to be passed to summary, currently only digits for rounding is supported |
A print out.
data(liarozole)
head(liarozole)
LiWi<-binomRDci(Improved ~ Treatment, data=liarozole,
type="Williams")
LiWi
summary(LiWi)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.