| summary.binomRDtest | R Documentation |
Produces a more detailed print out of objects of class "binomRDtest", including summary statistics, the used contrast matrix and the p-values.
## S3 method for class 'binomRDtest'
summary(object, ...)
object |
an object of class "binomRDtest" as created by function binomRDtest |
... |
further arguments to be passed to summary, currently only digits for rounding is supported |
A print out.
ntrials <- c(40,20,20,20)
xsuccesses <- c(1,2,2,4)
names(xsuccesses) <- LETTERS[1:4]
test<-binomRDtest(x=xsuccesses, n=ntrials, method="ADD1",
type="Changepoint", alternative="greater")
test
summary(test)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.