Learn R Programming

MCPAN (version 1.1-22)

summary.binomRRci: Detailed print out for binomRRci

Description

Produces a more detailed print out of objects of class "binomRRci", including summary statistics, the used contrast matrix and the confidence intervals.

Usage

# S3 method for binomRRci
summary(object, ...)

Value

A print out.

Arguments

object

an object of class "binomRRci" as created by function binomRRci

...

further arguments to be passed to summary, currently only digits for rounding is supported

Examples

Run this code



data(liarozole)

head(liarozole)

LiDu<-binomRRci(Improved ~ Treatment, data=liarozole,
 type="Dunnett", alternative="greater")

LiDu

summary(LiDu)



Run the code above in your browser using DataLab