| estSimpson | R Documentation |
Calculates the estimate of the Simpson index from a vector of counts.
estSimpson(x)
x |
a integer (numeric) vector, giving the counts of p species in a community |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.