scalechoice: Only for internal use.
Description
How to define scale parameters of the Weibull distribution in the poly-k-setting
Usage
scalechoice(shape = 3, pm = 0.2, t = 1)
Value
a single numeric value, giving the scale parameter needed to fulfill pm(t) for the current definition of the Weibull disstribution.
Arguments
- shape
shape parameter (usually shape=3)
- pm
a numeric value (0<p<1), probability that an individual dies before time t
- t
a numeric value, time t