Learn R Programming

MCPAN (version 1.1-22)

summary.binomRDtest: Detailed print out for binomRDtest

Description

Produces a more detailed print out of objects of class "binomRDtest", including summary statistics, the used contrast matrix and the p-values.

Usage

# S3 method for binomRDtest
summary(object, ...)

Value

A print out.

Arguments

object

an object of class "binomRDtest" as created by function binomRDtest

...

further arguments to be passed to summary, currently only digits for rounding is supported

Examples

Run this code


ntrials <- c(40,20,20,20)
xsuccesses <- c(1,2,2,4)
names(xsuccesses) <- LETTERS[1:4]
test<-binomRDtest(x=xsuccesses, n=ntrials, method="ADD1",
 type="Changepoint", alternative="greater")

test

summary(test)

Run the code above in your browser using DataLab